@@ -30,25 +30,25 @@ class TestDistro(BaseTest):
 		src = tempfile.NamedTemporaryFile()
 		try:
 			cache = distro.Cache('test-cache', src.name, 1)
-			self.assertEquals(None, cache.get("foo"))
+			self.assertEqual(None, cache.get("foo"))
 			cache.put("foo", "1")
-			self.assertEquals("1", cache.get("foo"))
+			self.assertEqual("1", cache.get("foo"))
 			cache.put("foo", "2")
-			self.assertEquals("2", cache.get("foo"))
+			self.assertEqual("2", cache.get("foo"))
 
 			# new cache...
 			cache = distro.Cache('test-cache', src.name, 1)
-			self.assertEquals("2", cache.get("foo"))
+			self.assertEqual("2", cache.get("foo"))
 
 			src.write("hi")
 			src.flush()
 
-			self.assertEquals(None, cache.get("foo"))
+			self.assertEqual(None, cache.get("foo"))
 			cache.put("foo", "3")
 
 			# new cache... (format change)
 			cache = distro.Cache('test-cache', src.name, 2)
-			self.assertEquals(None, cache.get("foo"))
+			self.assertEqual(None, cache.get("foo"))
 
 		finally:
 			src.close()
@@ -68,13 +68,13 @@ class TestDistro(BaseTest):
 
 		factory = self.make_factory(host)
 		host.get_package_info('gimp', factory)
-		self.assertEquals(self.feed.implementations, {})
+		self.assertEqual(self.feed.implementations, {})
 
 		# Special case: we can always find a version of Python
 		master_feed = model.ZeroInstallFeed(None)
 		master_feed.url = 'http://repo.roscidus.com/python/python'
 		feed = host.get_feed(master_feed)
-		self.assertEquals(1, len(feed.implementations))
+		self.assertEqual(1, len(feed.implementations))
 
 	def testDebian(self):
 		dpkgdir = os.path.join(os.path.dirname(__file__), 'dpkg')
@@ -85,11 +85,11 @@ class TestDistro(BaseTest):
 
 		factory = self.make_factory(host)
 		host.get_package_info('gimp', factory)
-		self.assertEquals({}, self.feed.implementations)
+		self.assertEqual({}, self.feed.implementations)
 
 		# Initially, we only get information about the installed version...
 		host.get_package_info('python-bittorrent', factory)
-		self.assertEquals(1, len(self.feed.implementations))
+		self.assertEqual(1, len(self.feed.implementations))
 
 		# Tell distro to fetch information about candidates...
 		master_feed = parse_impls("""<package-implementation package='python-bittorrent'/>""")
@@ -100,36 +100,36 @@ class TestDistro(BaseTest):
 		# Now we see the uninstalled package
 		self.feed = model.ZeroInstallFeed(empty_feed, local_path = '/empty.xml')
 		host.get_package_info('python-bittorrent', factory)
-		self.assertEquals(2, len(self.feed.implementations))
+		self.assertEqual(2, len(self.feed.implementations))
 
-		self.assertEquals(2, len(self.feed.implementations))
+		self.assertEqual(2, len(self.feed.implementations))
 		bittorrent_installed = self.feed.implementations['package:deb:python-bittorrent:3.4.2-10:*']
 		bittorrent_uninstalled = self.feed.implementations['package:deb:python-bittorrent:3.4.2-11.1:*']
-		self.assertEquals('3.4.2-10', bittorrent_installed.get_version())
+		self.assertEqual('3.4.2-10', bittorrent_installed.get_version())
 		self.assertTrue(bittorrent_installed.installed)
 		self.assertFalse(bittorrent_uninstalled.installed)
-		self.assertEquals(None, bittorrent_installed.machine)
+		self.assertEqual(None, bittorrent_installed.machine)
 
 		self.feed = model.ZeroInstallFeed(empty_feed, local_path = '/empty.xml')
 		host.get_package_info('libxcomposite-dev', factory)
-		self.assertEquals(1, len(self.feed.implementations))
+		self.assertEqual(1, len(self.feed.implementations))
 		libxcomposite = self.feed.implementations['package:deb:libxcomposite-dev:0.3.1-1:i386']
-		self.assertEquals('0.3.1-1', libxcomposite.get_version())
-		self.assertEquals('i386', libxcomposite.machine)
+		self.assertEqual('0.3.1-1', libxcomposite.get_version())
+		self.assertEqual('i386', libxcomposite.machine)
 	
 	def testRPM(self):
 		rpmdir = os.path.join(os.path.dirname(__file__), 'rpm')
 		os.environ['PATH'] = rpmdir + ':' + self.old_path
 		rpm = distro.RPMDistribution(os.path.join(rpmdir, 'status'))
 
-		self.assertEquals(2, len(rpm.versions))
+		self.assertEqual(2, len(rpm.versions))
 
 		factory = self.make_factory(rpm)
 		rpm.get_package_info('yast2-update', factory)
-		self.assertEquals(1, len(self.feed.implementations))
+		self.assertEqual(1, len(self.feed.implementations))
 		yast = self.feed.implementations['package:rpm:yast2-update:2.15.23-21:i586']
-		self.assertEquals('2.15.23-21', yast.get_version())
-		self.assertEquals('*-i586', yast.arch)
+		self.assertEqual('2.15.23-21', yast.get_version())
+		self.assertEqual('*-i586', yast.arch)
 
 		icache = iface_cache.IfaceCache(distro = rpm)
 
@@ -140,7 +140,7 @@ class TestDistro(BaseTest):
 		icache._feeds[feed.url] = feed
 		distro_feed_url = feed.get_distro_feed()
 		impls = icache.get_feed(distro_feed_url).implementations
-		self.assertEquals("distribution:myfeed.xml", distro_feed_url)
+		self.assertEqual("distribution:myfeed.xml", distro_feed_url)
 		assert len(impls) == 1, impls
 		impl, = impls
 		assert impl == 'package:rpm:yast2-update:2.15.23-21:i586'
@@ -169,13 +169,13 @@ class TestDistro(BaseTest):
 
 		factory = self.make_factory(slack)
 		slack.get_package_info('gimp', factory)
-		self.assertEquals({}, self.feed.implementations)
+		self.assertEqual({}, self.feed.implementations)
 
 		slack.get_package_info('infozip', factory)
-		self.assertEquals(1, len(self.feed.implementations))
+		self.assertEqual(1, len(self.feed.implementations))
 		zip = self.feed.implementations['package:slack:infozip:5.52-2:i486']
-		self.assertEquals('5.52-2', zip.get_version())
-		self.assertEquals('i486', zip.machine)
+		self.assertEqual('5.52-2', zip.get_version())
+		self.assertEqual('i486', zip.machine)
 
 	def testGentoo(self):
 		pkgdir = os.path.join(os.path.dirname(__file__), 'gentoo')
@@ -183,28 +183,28 @@ class TestDistro(BaseTest):
 
 		factory = self.make_factory(ebuilds)
 		ebuilds.get_package_info('media-gfx/gimp', factory)
-		self.assertEquals({}, self.feed.implementations)
+		self.assertEqual({}, self.feed.implementations)
 
 		ebuilds.get_package_info('sys-apps/portage', factory)
-		self.assertEquals(1, len(self.feed.implementations))
+		self.assertEqual(1, len(self.feed.implementations))
 		impl = self.feed.implementations['package:gentoo:sys-apps/portage:2.1.7.16:x86_64']
-		self.assertEquals('2.1.7.16', impl.get_version())
-		self.assertEquals('x86_64', impl.machine)
+		self.assertEqual('2.1.7.16', impl.get_version())
+		self.assertEqual('x86_64', impl.machine)
 
 		ebuilds.get_package_info('sys-kernel/gentoo-sources', factory)
-		self.assertEquals(3, len(self.feed.implementations))
+		self.assertEqual(3, len(self.feed.implementations))
 		impl = self.feed.implementations['package:gentoo:sys-kernel/gentoo-sources:2.6.30-4:i686']
-		self.assertEquals('2.6.30-4', impl.get_version())
-		self.assertEquals('i686', impl.machine)
+		self.assertEqual('2.6.30-4', impl.get_version())
+		self.assertEqual('i686', impl.machine)
 		impl = self.feed.implementations['package:gentoo:sys-kernel/gentoo-sources:2.6.32:x86_64']
-		self.assertEquals('2.6.32', impl.get_version())
-		self.assertEquals('x86_64', impl.machine)
+		self.assertEqual('2.6.32', impl.get_version())
+		self.assertEqual('x86_64', impl.machine)
 
 		ebuilds.get_package_info('app-emulation/emul-linux-x86-baselibs', factory)
-		self.assertEquals(4, len(self.feed.implementations))
+		self.assertEqual(4, len(self.feed.implementations))
 		impl = self.feed.implementations['package:gentoo:app-emulation/emul-linux-x86-baselibs:20100220:i386']
-		self.assertEquals('20100220', impl.get_version())
-		self.assertEquals('i386', impl.machine)
+		self.assertEqual('20100220', impl.get_version())
+		self.assertEqual('i386', impl.machine)
 
 	def testPorts(self):
 		pkgdir = os.path.join(os.path.dirname(__file__), 'ports')
@@ -212,10 +212,10 @@ class TestDistro(BaseTest):
 
 		factory = self.make_factory(ports)
 		ports.get_package_info('zeroinstall-injector', factory)
-		self.assertEquals(1, len(self.feed.implementations))
+		self.assertEqual(1, len(self.feed.implementations))
 		impl = self.feed.implementations['package:ports:zeroinstall-injector:0.41-2:' + distro.host_machine]
-		self.assertEquals('0.41-2', impl.get_version())
-		self.assertEquals(distro.host_machine, impl.machine)
+		self.assertEqual('0.41-2', impl.get_version())
+		self.assertEqual(distro.host_machine, impl.machine)
 
 	def testMacPorts(self):
 		pkgdir = os.path.join(os.path.dirname(__file__), 'macports')
@@ -224,16 +224,16 @@ class TestDistro(BaseTest):
 
 		factory = self.make_factory(ports)
 		ports.get_package_info('zeroinstall-injector', factory)
-		self.assertEquals(1, len(self.feed.implementations))
+		self.assertEqual(1, len(self.feed.implementations))
 		impl = self.feed.implementations['package:macports:zeroinstall-injector:1.0-0:*']
-		self.assertEquals('1.0-0', impl.get_version())
-		self.assertEquals(None, impl.machine)
+		self.assertEqual('1.0-0', impl.get_version())
+		self.assertEqual(None, impl.machine)
 
 	def testCleanVersion(self):
-		self.assertEquals('0.3.1-1', distro.try_cleanup_distro_version('1:0.3.1-1'))
-		self.assertEquals('0.3.1-1', distro.try_cleanup_distro_version('0.3.1-1ubuntu0'))
-		self.assertEquals('0.3-post1-rc2', distro.try_cleanup_distro_version('0.3-post1-rc2'))
-		self.assertEquals('0.3.1-2', distro.try_cleanup_distro_version('0.3.1-r2-r3'))
+		self.assertEqual('0.3.1-1', distro.try_cleanup_distro_version('1:0.3.1-1'))
+		self.assertEqual('0.3.1-1', distro.try_cleanup_distro_version('0.3.1-1ubuntu0'))
+		self.assertEqual('0.3-post1-rc2', distro.try_cleanup_distro_version('0.3-post1-rc2'))
+		self.assertEqual('0.3.1-2', distro.try_cleanup_distro_version('0.3.1-r2-r3'))
 
 if __name__ == '__main__':
 	unittest.main()
