@@ -7,7 +7,7 @@ from zeroinstall import _
 from zeroinstall.support import tasks
 from zeroinstall.injector import handler, download
 
-version = '1.4.1'
+version = '1.5'
 
 class GUIHandler(handler.Handler):
 	dl_callbacks = None		# Download -> [ callback ]
@@ -21,7 +21,7 @@ class GUIHandler(handler.Handler):
 		return False
 
 	def abort_all_downloads(self):
-		for dl in self.monitored_downloads.values():
+		for dl in self.monitored_downloads:
 			dl.abort()
 
 	def downloads_changed(self):
