@@ -64,7 +64,7 @@ class Cache(object):
 	# Throws an exception if the cache doesn't exist or has the wrong format.
 	def _load_cache(self):
 		self.cache = cache = {}
-		stream = file(os.path.join(self.cache_dir, self.cache_leaf))
+		stream = open(os.path.join(self.cache_dir, self.cache_leaf))
 		try:
 			for line in stream:
 				line = line.strip()
@@ -106,7 +106,7 @@ class Cache(object):
 		cache_path = os.path.join(self.cache_dir, self.cache_leaf)
 		self.cache[key] = value
 		try:
-			stream = file(cache_path, 'a')
+			stream = open(cache_path, 'a')
 			try:
 				stream.write('%s=%s\n' % (key, value))
 			finally:
@@ -239,6 +239,82 @@ class Distribution(object):
 			self._packagekit = packagekit.PackageKit()
 		return self._packagekit
 
+class WindowsDistribution(Distribution):
+	def get_package_info(self, package, factory):
+		def _is_64bit_windows():
+			import sys
+			p = sys.platform
+			import platform
+			bits, linkage = platform.architecture()
+			from win32process import IsWow64Process
+			if p == 'win64' or (p == 'win32' and IsWow64Process()): return True
+			elif p == 'win32': return False
+			else: raise Exception(_("WindowsDistribution may only be used on the Windows platform"))
+
+		def _read_hklm_reg(key_name, value_name):
+			from win32api import RegOpenKeyEx, RegQueryValueEx, RegCloseKey
+			from win32con import HKEY_LOCAL_MACHINE, KEY_READ
+			KEY_WOW64_64KEY = 0x0100
+			KEY_WOW64_32KEY	= 0x0200
+			if _is_64bit_windows():
+				try:
+					key32 = RegOpenKeyEx(HKEY_LOCAL_MACHINE, key_name, 0, KEY_READ | KEY_WOW64_32KEY)
+					(value32, _) = RegQueryValueEx(key32, value_name)
+					RegCloseKey(key32)
+				except:
+					value32 = ''
+				try:
+					key64 = RegOpenKeyEx(HKEY_LOCAL_MACHINE, key_name, 0, KEY_READ | KEY_WOW64_64KEY)
+					(value64, _) = RegQueryValueEx(key64, value_name)
+					RegCloseKey(key64)
+				except:
+					value64 = ''
+			else:
+				try:
+					key32 = RegOpenKeyEx(HKEY_LOCAL_MACHINE, key_name, 0, KEY_READ)
+					(value32, _) = RegQueryValueEx(key32, value_name)
+					RegCloseKey(key32)
+				except:
+					value32 = ''
+				value64 = ''
+			return (value32, value64)
+
+		if package == 'openjdk-6-jre':
+			(java32_home, java64_home) = _read_hklm_reg(r"SOFTWARE\JavaSoft\Java Runtime Environment\1.6", "JavaHome")
+			import os.path
+
+			if os.path.isfile(java32_home + r"\bin\java.exe"):
+				impl = factory('package:windows:%s:%s:%s' % (package, '6', 'i486'))
+				impl.machine = 'i486';
+				impl.version = model.parse_version('6')
+				impl.upstream_stability = model.packaged
+				impl.main = java32_home + r"\bin\java.exe"
+
+			if os.path.isfile(java64_home + r"\bin\java.exe"):
+				impl = factory('package:windows:%s:%s:%s' % (package, '6', 'x86_64'))
+				impl.machine = 'x86_64';
+				impl.version = model.parse_version('6')
+				impl.upstream_stability = model.packaged
+				impl.main = java64_home + r"\bin\java.exe"
+
+		if package == 'openjdk-6-jdk':
+			(java32_home, java64_home) = _read_hklm_reg(r"SOFTWARE\JavaSoft\Java Development Kit\1.6", "JavaHome")
+			import os.path
+
+			if os.path.isfile(java32_home + r"\bin\java.exe"):
+				impl = factory('package:windows:%s:%s:%s' % (package, '6', 'i486'))
+				impl.machine = 'i486';
+				impl.version = model.parse_version('6')
+				impl.upstream_stability = model.packaged
+				impl.main = java32_home + r"\bin\java.exe"
+
+			if os.path.isfile(java64_home + r"\bin\java.exe"):
+				impl = factory('package:windows:%s:%s:%s' % (package, '6', 'x86_64'))
+				impl.machine = 'x86_64';
+				impl.version = model.parse_version('6')
+				impl.upstream_stability = model.packaged
+				impl.main = java64_home + r"\bin\java.exe"
+
 class CachedDistribution(Distribution):
 	"""For distributions where querying the package database is slow (e.g. requires running
 	an external command), we cache the results.
@@ -267,7 +343,7 @@ class CachedDistribution(Distribution):
 	def _load_cache(self):
 		"""Load {cache_leaf} cache file into self.versions if it is available and up-to-date.
 		Throws an exception if the cache should be (re)created."""
-		stream = file(os.path.join(self.cache_dir, self.cache_leaf))
+		stream = open(os.path.join(self.cache_dir, self.cache_leaf))
 
 		cache_version = None
 		for line in stream:
@@ -534,7 +610,7 @@ class GentooDistribution(Distribution):
 
 		for filename in os.listdir(category_dir):
 			if filename.startswith(match_prefix) and filename[len(match_prefix)].isdigit():
-				name = file(os.path.join(category_dir, filename, 'PF')).readline().strip()
+				name = open(os.path.join(category_dir, filename, 'PF')).readline().strip()
 
 				match = re.search(_version_start_reqexp, name)
 				if match is None:
@@ -546,7 +622,7 @@ class GentooDistribution(Distribution):
 				if category == 'app-emulation' and name.startswith('emul-'):
 					__, __, machine, __ = name.split('-', 3)
 				else:
-					machine, __ = file(os.path.join(category_dir, filename, 'CHOST')).readline().split('-', 1)
+					machine, __ = open(os.path.join(category_dir, filename, 'CHOST')).readline().split('-', 1)
 				machine = arch.canonicalize_machine(machine)
 
 				impl = factory('package:gentoo:%s:%s:%s' % \
@@ -573,7 +649,7 @@ class PortsDistribution(Distribution):
 			pkgdir = os.path.join(self._pkgdir, pkgname)
 			if not os.path.isdir(pkgdir): continue
 
-			#contents = file(os.path.join(pkgdir, '+CONTENTS')).readline().strip()
+			#contents = open(os.path.join(pkgdir, '+CONTENTS')).readline().strip()
 
 			match = nameversion.search(pkgname)
 			if match is None:
@@ -659,7 +735,9 @@ def get_host_distribution():
 		_pkg_db = '/var/db/pkg'
 		_macports_db = '/opt/local/var/macports/registry/registry.db'
 
-		if os.path.isdir(_pkg_db):
+		if os.name == "nt":
+			_host_distribution = WindowsDistribution()
+		elif os.path.isdir(_pkg_db):
 			if sys.platform.startswith("linux"):
 				_host_distribution = GentooDistribution(_pkg_db)
 			elif sys.platform.startswith("freebsd"):
