@@ -76,12 +76,12 @@ class PendingFeed(object):
 		self.signed_data = signed_data
 		self.recheck()
 
-	def download_keys(self, handler, feed_hint = None, key_mirror = None):
+	def download_keys(self, fetcher, feed_hint = None, key_mirror = None):
 		"""Download any required GPG keys not already on our keyring.
 		When all downloads are done (successful or otherwise), add any new keys
 		to the keyring, L{recheck}.
-		@param handler: handler to manage the download
-		@type handler: L{handler.Handler}
+		@param fetcher: fetcher to manage the download (was Handler before version 1.5)
+		@type fetcher: L{fetcher.Fetcher}
 		@param key_mirror: URL of directory containing keys, or None to use feed's directory
 		@type key_mirror: str
 		"""
@@ -93,7 +93,7 @@ class PendingFeed(object):
 				import urlparse
 				key_url = urlparse.urljoin(key_mirror or self.url, '%s.gpg' % key_id)
 				info(_("Fetching key from %s"), key_url)
-				dl = handler.get_download(key_url, hint = feed_hint)
+				dl = fetcher.download_url(key_url, hint = feed_hint)
 				downloads[dl.downloaded] = (dl, dl.tempfile)
 				blockers.append(dl.downloaded)
 
@@ -292,7 +292,7 @@ class IfaceCache(object):
 
 		old_modified = None
 		if os.path.exists(cached):
-			old_xml = file(cached).read()
+			old_xml = open(cached).read()
 			if old_xml == new_xml:
 				debug(_("No change"))
 				# Update in-memory copy, in case someone else updated the disk copy
@@ -301,7 +301,7 @@ class IfaceCache(object):
 			old_modified = int(os.stat(cached).st_mtime)
 
 		# Do we need to write this temporary file now?
-		stream = file(cached + '.new', 'w')
+		stream = open(cached + '.new', 'w')
 		stream.write(new_xml)
 		stream.close()
 		os.utime(cached + '.new', (modified_time, modified_time))
@@ -411,7 +411,7 @@ class IfaceCache(object):
 			if old_iface is None:
 				return None
 		try:
-			return gpg.check_stream(file(old_iface))[1]
+			return gpg.check_stream(open(old_iface))[1]
 		except SafeException as ex:
 			debug(_("No signatures (old-style interface): %s") % ex)
 			return None
